@@ -108,9 +108,9 @@ static guint osc_builder_signals[LAST_SIGNAL];
 GType
 ags_osc_builder_get_type(void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_osc_builder = 0;
 
     static const GTypeInfo ags_osc_builder_info = {
@@ -129,10 +129,10 @@ ags_osc_builder_get_type(void)
 						  "AgsOscBuilder", &ags_osc_builder_info,
 						  0);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_osc_builder);
+    g_once_init_leave(&g_define_type_id__static, ags_type_osc_builder);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
